@@ -26,6 +26,7 @@ import org.gnu.gtk.TreeSortable;
 import org.gnu.gtk.TreeStore;
 import org.gnu.gtk.TreeView;
 import org.gnu.gtk.TreeViewColumn;
+import org.gnu.gtk.TreeViewRowSeparatorMethod;
 import org.gnu.gtk.VBox;
 import org.gnu.gtk.Window;
 import org.gnu.gtk.WindowType;
@@ -138,6 +139,8 @@ public class TestTree {
         sortable = new TreeModelSort( filter );
         // Set the view to be the filtered-sorted list.
         treeWidget.setModel( sortable );
+        // Set to display the dataBool=false rows as separators.
+        //treeWidget.setRowSeparatorMethod( new RowSeparator() );
 
         // Create the Type column.
 	TreeViewColumn column = new TreeViewColumn();
@@ -216,6 +219,12 @@ public class TestTree {
         }
     }
 
+    protected class RowSeparator implements TreeViewRowSeparatorMethod {
+        public boolean isSeparator( TreeModel model, TreeIter iter ) {
+            return !model.getValue( iter, dataBool );
+        }
+    }
+
     protected class CheckFilterListener implements ToggleListener {
         public void toggleEvent( ToggleEvent event ) {
             // Re-filter the list.
