@@ -36,7 +36,7 @@ public class DragContext extends GObject
 	 */
 	public Window getSource() {
 	    Handle hndl = getSourceWindow(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Window)obj;
 		return new Window(hndl);
@@ -47,7 +47,7 @@ public class DragContext extends GObject
 	 */
 	public Window getDestination() {
 	    Handle hndl = getDestWindow(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Window)obj;
 		return new Window(hndl);
