@@ -36,9 +36,14 @@ public class EventButton extends Boxed
 		return EventButton.getType(handle);
 	}
 	
-    /****************************************
-     * BEGINNING OF GENERATED CODE
-     ****************************************/
+    public Window getWindow() {
+        return new Window(getWindow(getHandle()));
+    }
+
+    public Device getDevice() {
+        return new Device(getDevice(getHandle()));
+    }
+
     native static final protected int getType (Handle obj);
     native static final protected Handle getWindow (Handle obj);
     native static final protected boolean getSendEvent (Handle obj);
@@ -50,8 +55,6 @@ public class EventButton extends Boxed
     native static final protected Handle getDevice (Handle obj);
     native static final protected double getXRoot (Handle obj);
     native static final protected double getYRoot (Handle obj);
-    /****************************************
-     * END OF GENERATED CODE
-     ****************************************/
+
 }
 
