@@ -61,10 +61,14 @@ public class TextBuffer extends GObject {
 	}
 
 	/**
-	 * Gets the number of characters in the buffer; note that characters and
-	 * bytes are not the same, you can't e.g. expect the contents of the buffer
-	 * in string form to be this many bytes long. The character count is cached,
-	 * so this function is very fast.
+ Gets the number of characters in the buffer. Note that
+	 * characters and
+ bytes are not the same. You can't expect
+	 * the contents of the buffer
+ in string form to be this many
+	 * bytes long. The character count is cached,
+ so this
+	 * function is very fast.
 	 * @return Number of characters in the buffer.
 	 */
 	public int getCharCount() {
@@ -77,7 +81,7 @@ public class TextBuffer extends GObject {
 	 */
 	public TextTagTable getTextTagTable() {
 	    Handle hndl = gtk_text_buffer_get_tag_table(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (TextTagTable)obj;
 		return new TextTagTable(hndl);
@@ -391,7 +395,7 @@ public class TextBuffer extends GObject {
 	    Handle markHandle = gtk_text_buffer_get_mark(getHandle(), name);
 		if (null == markHandle)
 			return null;
-		GObject obj = retrieveGObject(markHandle);
+		GObject obj = getGObjectFromHandle(markHandle);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(markHandle);
@@ -405,7 +409,7 @@ public class TextBuffer extends GObject {
 	 */
 	public TextMark getInsert() {
 	    Handle hndl = gtk_text_buffer_get_insert(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(hndl);
@@ -423,7 +427,7 @@ public class TextBuffer extends GObject {
 	 */
 	public TextMark getSelectionBound() {
 	    Handle hndl = gtk_text_buffer_get_selection_bound(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (TextMark)obj;
 		return new TextMark(hndl);
@@ -591,7 +595,7 @@ public class TextBuffer extends GObject {
 	 * of the selection will be considered (users can't delete uneditable text).
 	 * @param interactive Whether the deletion is caused by user interaction
 	 * @param defaultEditable Whether the buffer is editable by default
-	 * @returns Whether there was a non-empty selection to delete
+	 * @return Whether there was a non-empty selection to delete
 	 */
 	public boolean deleteSelection(boolean interactive, boolean defaultEditable) {
 		return gtk_text_buffer_delete_selection(getHandle(), interactive, defaultEditable);
@@ -734,6 +738,30 @@ public class TextBuffer extends GObject {
 		gtk_text_buffer_select_range    (getHandle(), ins.getHandle(), bound.getHandle() );
 	}
 
+    /**
+     * Performs the appropriate action as if the user hit the delete
+     * key with the cursor at the position specified by iter. In the
+     * normal case a single character will be deleted, but when
+     * combining accents are involved, more than one character can be
+     * deleted, and when precomposed character and accent combinations
+     * are involved, less than one character will be deleted.
+     *
+     * Because the buffer is modified, all outstanding iterators
+     * become invalid after calling this function; however, the iter
+     * will be re-initialized to point to the location where text was
+     * deleted.
+     *
+     * @param iter A position in the buffer.
+     * @param interactive Whether the deletion is caused by user interaction.
+     * @param default_editable Whether the buffer is editable by default.
+     * @return TRUE if the buffer was modified.
+     */
+    public boolean backspace( TextIter iter, boolean interactive, 
+                              boolean default_editable ) {
+        return gtk_text_buffer_backspace( getHandle(), iter.getHandle(),
+                                          interactive, default_editable );
+    }
+
 	/****************************************
 	 * TextView event handling.
 	 ****************************************/
@@ -847,7 +875,7 @@ public class TextBuffer extends GObject {
 		return list.indexOf(listener);
 	}
 
-	private void handleApplyTag(int tag, int startIter, int endIter) {
+	private void handleApplyTag(Handle tag, Handle startIter, Handle endIter) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.APPLY_TAG));
 	}
 
@@ -855,27 +883,27 @@ public class TextBuffer extends GObject {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.CHANGED));
 	}
 
-	private void handleDeleteRange(int startIter, int endIter) {
+	private void handleDeleteRange(Handle startIter, Handle endIter) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.DELETE_RANGE));
 	}
 
-	private void handleInsertChildAnchor(int position, int childAnchor) {
+	private void handleInsertChildAnchor(Handle position, Handle childAnchor) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_CHILD_ANCHOR));
 	}
 
-	private void handleInsertPixbuf(int position, int pixbuf) {
+	private void handleInsertPixbuf(Handle position, Handle pixbuf) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_PIXBUF));
 	}
 
-	private void handleInsertText(int position, String text, int length) {
+	private void handleInsertText(Handle position, String text, int length) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.INSERT_TEXT));
 	}
 
-	private void handleMarkDelete(int mark) {
+	private void handleMarkDelete(Handle mark) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MARK_DELETED));
 	}
 
-	private void handleMarkSet(int location, int mark) {
+	private void handleMarkSet(Handle location, Handle mark) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MARK_SET));
 	}
 
@@ -883,7 +911,7 @@ public class TextBuffer extends GObject {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.MODIFIED_CHANGED));
 	}
 
-	private void handleRemoveTag(int tag, int startChar, int endChar) {
+	private void handleRemoveTag(Handle tag, Handle startChar, Handle endChar) {
 		fireTextBufferEvent(new TextBufferEvent(this, TextBufferEvent.Type.REMOVE_TAG));
 	}
 
@@ -969,4 +997,7 @@ public class TextBuffer extends GObject {
 	native static final protected Handle gtk_text_buffer_get_start_iterMOD(Handle buffer);
 	native static final protected Handle gtk_text_buffer_get_end_iterMOD(Handle buffer);
 	native protected static final void gtk_text_buffer_paste_clipboardInsertPosition(Handle handle, Handle clip, boolean editable);
+
+    // GTK 2.6 additions.
+    native static final private boolean gtk_text_buffer_backspace(Handle buffer, Handle iter, boolean interactive, boolean default_editable);
 }
